@@ -918,7 +918,7 @@ pango_fc_font_map_new_font (PangoFontMap               *fontmap,
 	{
 	  FcMatrix fc_matrix;
 	  
-	  /* FontConfig has the Y axis pointing up, Pango, down.
+	  /* Fontconfig has the Y axis pointing up, Pango, down.
 	   */
 	  fc_matrix.xx = pango_matrix->xx;
 	  fc_matrix.xy = - pango_matrix->xy;
@@ -1473,7 +1473,7 @@ cleanup_font (gpointer        key,
  * 
  * Clears all cached information for the fontmap and marks
  * all fonts open for the fontmap as dead. (See the shutdown()
- * virtual function of PangoFcFont.) This function might be used
+ * virtual function of #PangoFcFont.) This function might be used
  * by a backend when the underlying windowing system for the font
  * map exits. This function is only intended to be called from
  * only for backend implementations deriving from #PangoFcFontmap.
@@ -1704,7 +1704,10 @@ pango_fc_face_describe (PangoFontFace *face)
 				  NULL);
 
   g_assert (match_pattern);
-  
+
+  FcConfigSubstitute (NULL, match_pattern, FcMatchPattern);
+  FcDefaultSubstitute (match_pattern);
+
   result_pattern = FcFontMatch (NULL, match_pattern, &res);
   if (result_pattern)
     {
