@@ -62,8 +62,6 @@ struct _PangoFT2FontMapClass
 };
 
 static void          pango_ft2_font_map_finalize            (GObject              *object);
-static void          pango_ft2_font_map_default_substitute  (PangoFcFontMap       *fcfontmap,
-							     FcPattern            *pattern);
 static PangoFcFont * pango_ft2_font_map_new_font            (PangoFcFontMap       *fcfontmap,
 							     FcPattern            *pattern);
 static double        pango_ft2_font_map_get_resolution      (PangoFcFontMap       *fcfontmap,
@@ -80,7 +78,7 @@ pango_ft2_font_map_class_init (PangoFT2FontMapClass *class)
   PangoFcFontMapClass *fcfontmap_class = PANGO_FC_FONT_MAP_CLASS (class);
   
   gobject_class->finalize = pango_ft2_font_map_finalize;
-  fcfontmap_class->default_substitute = pango_ft2_font_map_default_substitute;
+  fcfontmap_class->default_substitute = _pango_ft2_font_map_default_substitute;
   fcfontmap_class->new_font = pango_ft2_font_map_new_font;
   fcfontmap_class->get_resolution = pango_ft2_font_map_get_resolution;
 }
@@ -179,7 +177,7 @@ pango_ft2_font_map_set_default_substitute (PangoFT2FontMap        *fontmap,
  * Call this function any time the results of the
  * default substitution function set with
  * pango_ft2_font_map_set_default_substitute() change.
- * That is, if your subsitution function will return different
+ * That is, if your substitution function will return different
  * results for the same input pattern, you must call this function.
  *
  * Since: 1.2
@@ -233,8 +231,8 @@ pango_ft2_font_map_create_context (PangoFT2FontMap *fontmap)
 
 /**
  * pango_ft2_get_context:
- * @dpi_x:  the horizontal dpi of the target device
- * @dpi_y:  the vertical dpi of the target device
+ * @dpi_x:  the horizontal DPI of the target device
+ * @dpi_y:  the vertical DPI of the target device
  * 
  * Retrieves a #PangoContext for the default PangoFT2 fontmap
  * (see pango_ft2_fontmap_get_for_display()) and sets the resolution
@@ -323,8 +321,8 @@ _pango_ft2_font_map_get_renderer (PangoFT2FontMap *ft2fontmap)
   return ft2fontmap->renderer;
 }
 
-static void
-pango_ft2_font_map_default_substitute (PangoFcFontMap *fcfontmap,
+void
+_pango_ft2_font_map_default_substitute (PangoFcFontMap *fcfontmap,
 				       FcPattern      *pattern)
 {
   PangoFT2FontMap *ft2fontmap = PANGO_FT2_FONT_MAP (fcfontmap);
